@@ -2,7 +2,7 @@
 /*
  *  nsc-gstreamer.c
  * 
- *  Copyright (C) 2008-2009 Brian Pepple
+ *  Copyright (C) 2008-2010 Brian Pepple
  *  Copyright (C) 2003-2007 Ross Burton <ross@burtonini.com>
  *
  *  This library is free software; you can redistribute it and/or
@@ -594,6 +594,9 @@ nsc_gstreamer_cancel_convert (NscGStreamer *gstreamer)
 {
 	NscGStreamerPrivate *priv;
 	GstState             state;
+	GFile               *sink_file;
+	gchar               *sink_uri;
+	GError              *error = NULL;
 
 	g_return_if_fail (NSC_IS_GSTREAMER (gstreamer));
 
@@ -610,6 +613,27 @@ nsc_gstreamer_cancel_convert (NscGStreamer *gstreamer)
 
 	gst_element_set_state (priv->pipeline, GST_STATE_NULL);
 
+	/*
+	 * Remove the file that was being converted
+	 * when the cancel button was pressed.
+	 */
+	g_object_get (G_OBJECT (priv->filesink),
+		      "location", &sink_uri,
+		      NULL);
+
+	sink_file = g_file_new_for_uri (sink_uri);
+	g_file_delete (sink_file, NULL, &error);
+
+	if (error) {
+		g_warning ("Unable to delete file; %s", error->message);
+		g_error_free (error);
+	}
+
+	if (sink_file)
+		g_object_unref (sink_file);
+
+	g_free (sink_uri);
+
 	priv->rebuild_pipeline = TRUE;
 }
 
@@ -682,6 +706,23 @@ nsc_gstreamer_supports_musepack (GError **error)
 	return TRUE;
 }
 
+gboolean
+nsc_gstreamer_supports_wma (GError **error)
+{
+	GstElement *element = NULL;
+
+	element = gst_element_factory_make ("ffdec_wmav2", "test");
+	if (element == NULL) {
+		g_set_error (error, NSC_ERROR, NSC_ERROR_INTERNAL_ERROR,
+			     _("The plugin necessary for wma file access was not found"));
+		return FALSE;
+	}
+
+	g_object_unref (element);
+
+	return TRUE;
+}
+
 gboolean
 nsc_gstreamer_supports_profile (GMAudioProfile *profile)
 {
